# coding: utf-8

"""
    model-information-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from dhicn_model_information_service.api_client import ApiClient
from dhicn_model_information_service.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class WDModelEditApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_v1_model_information_domain_wd_control_ts_add_post(self, **kwargs):  # noqa: E501
        """新增控制规则时序数据 Add control time-series data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_control_ts_add_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddControlTsInput add_control_ts_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_domain_wd_control_ts_add_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_domain_wd_control_ts_add_post_with_http_info(self, **kwargs):  # noqa: E501
        """新增控制规则时序数据 Add control time-series data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_control_ts_add_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddControlTsInput add_control_ts_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_control_ts_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_domain_wd_control_ts_add_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_control_ts_input' in local_var_params:
            body_params = local_var_params['add_control_ts_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/domain-wd/control-ts/add', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_domain_wd_control_ts_all_get(self, **kwargs):  # noqa: E501
        """获取所有的控制规则时序数据 Get all control time-series data of a scenario  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_control_ts_all_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案ID scenario id
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[ControlTsDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_domain_wd_control_ts_all_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_domain_wd_control_ts_all_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取所有的控制规则时序数据 Get all control time-series data of a scenario  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_control_ts_all_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案ID scenario id
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[ControlTsDto], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_domain_wd_control_ts_all_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('scenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/domain-wd/control-ts/all', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ControlTsDto]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_domain_wd_control_ts_delete_post(self, **kwargs):  # noqa: E501
        """删除控制规则时序数据 Delete control time-series data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_control_ts_delete_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param DeleteControlTsInput delete_control_ts_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_domain_wd_control_ts_delete_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_domain_wd_control_ts_delete_post_with_http_info(self, **kwargs):  # noqa: E501
        """删除控制规则时序数据 Delete control time-series data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_control_ts_delete_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param DeleteControlTsInput delete_control_ts_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'delete_control_ts_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_domain_wd_control_ts_delete_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'delete_control_ts_input' in local_var_params:
            body_params = local_var_params['delete_control_ts_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/domain-wd/control-ts/delete', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_domain_wd_control_ts_get_by_modeid_get(self, **kwargs):  # noqa: E501
        """获取指定模型id的控制规则时序数据 Get control time-series data of a scenario by muid  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_control_ts_get_by_modeid_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案ID scenario id
        :param str model_id: 模型中控制规则的ID control muid
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ControlTsDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_domain_wd_control_ts_get_by_modeid_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_domain_wd_control_ts_get_by_modeid_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取指定模型id的控制规则时序数据 Get control time-series data of a scenario by muid  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_control_ts_get_by_modeid_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案ID scenario id
        :param str model_id: 模型中控制规则的ID control muid
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ControlTsDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id',
            'model_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_domain_wd_control_ts_get_by_modeid_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('scenarioId', local_var_params['scenario_id']))  # noqa: E501
        if 'model_id' in local_var_params and local_var_params['model_id'] is not None:  # noqa: E501
            query_params.append(('modelId', local_var_params['model_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/domain-wd/control-ts/get-by-modeid', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ControlTsDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_domain_wd_control_ts_getlist_by_modelid_post(self, **kwargs):  # noqa: E501
        """根据模型id列表获取控制规则时序数据 Get control time-series data of a scenario by muids  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_control_ts_getlist_by_modelid_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param GetControlTsListyModelIdInput get_control_ts_listy_model_id_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[ControlTsDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_domain_wd_control_ts_getlist_by_modelid_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_domain_wd_control_ts_getlist_by_modelid_post_with_http_info(self, **kwargs):  # noqa: E501
        """根据模型id列表获取控制规则时序数据 Get control time-series data of a scenario by muids  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_control_ts_getlist_by_modelid_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param GetControlTsListyModelIdInput get_control_ts_listy_model_id_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[ControlTsDto], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'get_control_ts_listy_model_id_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_domain_wd_control_ts_getlist_by_modelid_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'get_control_ts_listy_model_id_input' in local_var_params:
            body_params = local_var_params['get_control_ts_listy_model_id_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/domain-wd/control-ts/getlist-by-modelid', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ControlTsDto]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_domain_wd_control_ts_resave_post(self, **kwargs):  # noqa: E501
        """保存控制规则时序数据，原有控制规则时序数据会被删除 Save control time-series data, old control time-series data will be deleted  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_control_ts_resave_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddControlTsInput add_control_ts_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_domain_wd_control_ts_resave_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_domain_wd_control_ts_resave_post_with_http_info(self, **kwargs):  # noqa: E501
        """保存控制规则时序数据，原有控制规则时序数据会被删除 Save control time-series data, old control time-series data will be deleted  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_control_ts_resave_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddControlTsInput add_control_ts_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_control_ts_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_domain_wd_control_ts_resave_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_control_ts_input' in local_var_params:
            body_params = local_var_params['add_control_ts_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/domain-wd/control-ts/resave', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_domain_wd_control_ts_update_post(self, **kwargs):  # noqa: E501
        """修改控制规则时序数据 Update control time-series data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_control_ts_update_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateControlTsInput update_control_ts_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_domain_wd_control_ts_update_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_domain_wd_control_ts_update_post_with_http_info(self, **kwargs):  # noqa: E501
        """修改控制规则时序数据 Update control time-series data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_control_ts_update_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateControlTsInput update_control_ts_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_control_ts_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_domain_wd_control_ts_update_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_control_ts_input' in local_var_params:
            body_params = local_var_params['update_control_ts_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/domain-wd/control-ts/update', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_domain_wd_curve_relation_ts_add_post(self, **kwargs):  # noqa: E501
        """新增曲线时序数据 Add curve time-series data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_curve_relation_ts_add_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddCurveRelationTsInput add_curve_relation_ts_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_domain_wd_curve_relation_ts_add_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_domain_wd_curve_relation_ts_add_post_with_http_info(self, **kwargs):  # noqa: E501
        """新增曲线时序数据 Add curve time-series data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_curve_relation_ts_add_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddCurveRelationTsInput add_curve_relation_ts_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_curve_relation_ts_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_domain_wd_curve_relation_ts_add_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_curve_relation_ts_input' in local_var_params:
            body_params = local_var_params['add_curve_relation_ts_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/domain-wd/curve-relation-ts/add', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_domain_wd_curve_relation_ts_all_get(self, **kwargs):  # noqa: E501
        """获取所有的曲线时序数据 Get all curve time-series data of a scenario  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_curve_relation_ts_all_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案ID scenario id
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[CurveRelationTsDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_domain_wd_curve_relation_ts_all_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_domain_wd_curve_relation_ts_all_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取所有的曲线时序数据 Get all curve time-series data of a scenario  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_curve_relation_ts_all_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案ID scenario id
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[CurveRelationTsDto], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_domain_wd_curve_relation_ts_all_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('scenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/domain-wd/curve-relation-ts/all', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[CurveRelationTsDto]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_domain_wd_curve_relation_ts_delete_post(self, **kwargs):  # noqa: E501
        """删除曲线时序数据 Delete curve time-series data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_curve_relation_ts_delete_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param DeleteCurveRelationTsInput delete_curve_relation_ts_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_domain_wd_curve_relation_ts_delete_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_domain_wd_curve_relation_ts_delete_post_with_http_info(self, **kwargs):  # noqa: E501
        """删除曲线时序数据 Delete curve time-series data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_curve_relation_ts_delete_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param DeleteCurveRelationTsInput delete_curve_relation_ts_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'delete_curve_relation_ts_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_domain_wd_curve_relation_ts_delete_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'delete_curve_relation_ts_input' in local_var_params:
            body_params = local_var_params['delete_curve_relation_ts_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/domain-wd/curve-relation-ts/delete', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_domain_wd_curve_relation_ts_get_by_modelid_get(self, **kwargs):  # noqa: E501
        """获取指定模型id的曲线时序数据 Get curve time-series data of a scenario by muid  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_curve_relation_ts_get_by_modelid_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案ID scenario id
        :param str model_id: 模型中曲线ID curve id
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CurveRelationTsDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_domain_wd_curve_relation_ts_get_by_modelid_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_domain_wd_curve_relation_ts_get_by_modelid_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取指定模型id的曲线时序数据 Get curve time-series data of a scenario by muid  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_curve_relation_ts_get_by_modelid_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案ID scenario id
        :param str model_id: 模型中曲线ID curve id
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CurveRelationTsDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id',
            'model_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_domain_wd_curve_relation_ts_get_by_modelid_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('scenarioId', local_var_params['scenario_id']))  # noqa: E501
        if 'model_id' in local_var_params and local_var_params['model_id'] is not None:  # noqa: E501
            query_params.append(('modelId', local_var_params['model_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/domain-wd/curve-relation-ts/get-by-modelid', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CurveRelationTsDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_domain_wd_curve_relation_ts_getlist_by_modelid_post(self, **kwargs):  # noqa: E501
        """根据模型id列表获取曲线时序数据 Get curve time-series data of a scenario by muids  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_curve_relation_ts_getlist_by_modelid_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param GetCurveRelationTsListyModelIdInput get_curve_relation_ts_listy_model_id_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[CurveRelationTsDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_domain_wd_curve_relation_ts_getlist_by_modelid_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_domain_wd_curve_relation_ts_getlist_by_modelid_post_with_http_info(self, **kwargs):  # noqa: E501
        """根据模型id列表获取曲线时序数据 Get curve time-series data of a scenario by muids  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_curve_relation_ts_getlist_by_modelid_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param GetCurveRelationTsListyModelIdInput get_curve_relation_ts_listy_model_id_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[CurveRelationTsDto], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'get_curve_relation_ts_listy_model_id_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_domain_wd_curve_relation_ts_getlist_by_modelid_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'get_curve_relation_ts_listy_model_id_input' in local_var_params:
            body_params = local_var_params['get_curve_relation_ts_listy_model_id_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/domain-wd/curve-relation-ts/getlist-by-modelid', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[CurveRelationTsDto]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_domain_wd_curve_relation_ts_resave_post(self, **kwargs):  # noqa: E501
        """保存曲线时序数据，原有曲线时序数据会被删除 Save curve time-series data, old curve time-series data will be deleted  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_curve_relation_ts_resave_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddCurveRelationTsInput add_curve_relation_ts_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_domain_wd_curve_relation_ts_resave_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_domain_wd_curve_relation_ts_resave_post_with_http_info(self, **kwargs):  # noqa: E501
        """保存曲线时序数据，原有曲线时序数据会被删除 Save curve time-series data, old curve time-series data will be deleted  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_curve_relation_ts_resave_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddCurveRelationTsInput add_curve_relation_ts_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_curve_relation_ts_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_domain_wd_curve_relation_ts_resave_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_curve_relation_ts_input' in local_var_params:
            body_params = local_var_params['add_curve_relation_ts_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/domain-wd/curve-relation-ts/resave', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_domain_wd_curve_relation_ts_update_post(self, **kwargs):  # noqa: E501
        """修改曲线时序数据 Update curve time-series data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_curve_relation_ts_update_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateCurveRelationTsInput update_curve_relation_ts_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_domain_wd_curve_relation_ts_update_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_domain_wd_curve_relation_ts_update_post_with_http_info(self, **kwargs):  # noqa: E501
        """修改曲线时序数据 Update curve time-series data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_curve_relation_ts_update_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateCurveRelationTsInput update_curve_relation_ts_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_curve_relation_ts_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_domain_wd_curve_relation_ts_update_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_curve_relation_ts_input' in local_var_params:
            body_params = local_var_params['update_curve_relation_ts_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/domain-wd/curve-relation-ts/update', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_domain_wd_flushing_para_add_post(self, **kwargs):  # noqa: E501
        """新增管道冲洗参数设置 Add pipe flushing parameters  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_flushing_para_add_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddFlushingParaInput add_flushing_para_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_domain_wd_flushing_para_add_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_domain_wd_flushing_para_add_post_with_http_info(self, **kwargs):  # noqa: E501
        """新增管道冲洗参数设置 Add pipe flushing parameters  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_flushing_para_add_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddFlushingParaInput add_flushing_para_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_flushing_para_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_domain_wd_flushing_para_add_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_flushing_para_input' in local_var_params:
            body_params = local_var_params['add_flushing_para_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/domain-wd/flushing/para/add', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_domain_wd_flushing_para_delete_post(self, **kwargs):  # noqa: E501
        """删除管道冲洗参数设置 Delete pipe flushing parameters  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_flushing_para_delete_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param DeleteFlushingParaInput delete_flushing_para_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_domain_wd_flushing_para_delete_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_domain_wd_flushing_para_delete_post_with_http_info(self, **kwargs):  # noqa: E501
        """删除管道冲洗参数设置 Delete pipe flushing parameters  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_flushing_para_delete_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param DeleteFlushingParaInput delete_flushing_para_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'delete_flushing_para_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_domain_wd_flushing_para_delete_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'delete_flushing_para_input' in local_var_params:
            body_params = local_var_params['delete_flushing_para_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/domain-wd/flushing/para/delete', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_domain_wd_flushing_para_get_get(self, **kwargs):  # noqa: E501
        """查询管道冲洗参数设置 Get pipe flushing parameters of a scenario  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_flushing_para_get_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案ID scenario id
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: FlushingParaDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_domain_wd_flushing_para_get_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_domain_wd_flushing_para_get_get_with_http_info(self, **kwargs):  # noqa: E501
        """查询管道冲洗参数设置 Get pipe flushing parameters of a scenario  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_flushing_para_get_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案ID scenario id
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(FlushingParaDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_domain_wd_flushing_para_get_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('scenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/domain-wd/flushing/para/get', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FlushingParaDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_domain_wd_flushing_para_resave_post(self, **kwargs):  # noqa: E501
        """保存管道冲洗参数信息，原有管道冲洗参数信息会被删除 Save pipe flushing parameters, old pipe flushing parameters will be deleted  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_flushing_para_resave_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddFlushingParaInput add_flushing_para_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_domain_wd_flushing_para_resave_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_domain_wd_flushing_para_resave_post_with_http_info(self, **kwargs):  # noqa: E501
        """保存管道冲洗参数信息，原有管道冲洗参数信息会被删除 Save pipe flushing parameters, old pipe flushing parameters will be deleted  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_flushing_para_resave_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddFlushingParaInput add_flushing_para_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_flushing_para_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_domain_wd_flushing_para_resave_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_flushing_para_input' in local_var_params:
            body_params = local_var_params['add_flushing_para_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/domain-wd/flushing/para/resave', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_domain_wd_flushing_para_update_post(self, **kwargs):  # noqa: E501
        """修改管道冲洗参数设置 Update pipe flushing parameters  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_flushing_para_update_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateFlushingParaInput update_flushing_para_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_domain_wd_flushing_para_update_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_domain_wd_flushing_para_update_post_with_http_info(self, **kwargs):  # noqa: E501
        """修改管道冲洗参数设置 Update pipe flushing parameters  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_flushing_para_update_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateFlushingParaInput update_flushing_para_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_flushing_para_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_domain_wd_flushing_para_update_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_flushing_para_input' in local_var_params:
            body_params = local_var_params['update_flushing_para_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/domain-wd/flushing/para/update', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_domain_wd_pattern_ts_add_post(self, **kwargs):  # noqa: E501
        """新增模式时序数据 Add pattern time-series data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_pattern_ts_add_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddPatternTsInput add_pattern_ts_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_domain_wd_pattern_ts_add_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_domain_wd_pattern_ts_add_post_with_http_info(self, **kwargs):  # noqa: E501
        """新增模式时序数据 Add pattern time-series data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_pattern_ts_add_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddPatternTsInput add_pattern_ts_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_pattern_ts_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_domain_wd_pattern_ts_add_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_pattern_ts_input' in local_var_params:
            body_params = local_var_params['add_pattern_ts_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/domain-wd/pattern-ts/add', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_domain_wd_pattern_ts_all_get(self, **kwargs):  # noqa: E501
        """获取所有的模式时序数据 Get all pattern time-series data of a scenario  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_pattern_ts_all_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案ID scenario id
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[PatternTsDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_domain_wd_pattern_ts_all_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_domain_wd_pattern_ts_all_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取所有的模式时序数据 Get all pattern time-series data of a scenario  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_pattern_ts_all_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案ID scenario id
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[PatternTsDto], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_domain_wd_pattern_ts_all_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('scenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/domain-wd/pattern-ts/all', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PatternTsDto]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_domain_wd_pattern_ts_delete_post(self, **kwargs):  # noqa: E501
        """删除模式时序数据 Delete pattern time-series data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_pattern_ts_delete_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param DeletePatternTsInput delete_pattern_ts_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_domain_wd_pattern_ts_delete_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_domain_wd_pattern_ts_delete_post_with_http_info(self, **kwargs):  # noqa: E501
        """删除模式时序数据 Delete pattern time-series data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_pattern_ts_delete_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param DeletePatternTsInput delete_pattern_ts_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'delete_pattern_ts_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_domain_wd_pattern_ts_delete_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'delete_pattern_ts_input' in local_var_params:
            body_params = local_var_params['delete_pattern_ts_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/domain-wd/pattern-ts/delete', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_domain_wd_pattern_ts_get_by_modelid_get(self, **kwargs):  # noqa: E501
        """获取指定模型id的模式时序数据 Get pattern time-series data of a scenario by pattern muid  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_pattern_ts_get_by_modelid_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案ID scenario id
        :param str model_id: 模型中模式的ID pattern muid
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: PatternTsDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_domain_wd_pattern_ts_get_by_modelid_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_domain_wd_pattern_ts_get_by_modelid_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取指定模型id的模式时序数据 Get pattern time-series data of a scenario by pattern muid  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_pattern_ts_get_by_modelid_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案ID scenario id
        :param str model_id: 模型中模式的ID pattern muid
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(PatternTsDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id',
            'model_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_domain_wd_pattern_ts_get_by_modelid_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('scenarioId', local_var_params['scenario_id']))  # noqa: E501
        if 'model_id' in local_var_params and local_var_params['model_id'] is not None:  # noqa: E501
            query_params.append(('modelId', local_var_params['model_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/domain-wd/pattern-ts/get-by-modelid', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PatternTsDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_domain_wd_pattern_ts_get_by_type_get(self, **kwargs):  # noqa: E501
        """获取指定类型的模式时序数据 Get pattern time-series data of a scenario by type  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_pattern_ts_get_by_type_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案ID scenario id
        :param str pattern_type: 模式类型 pattern type
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[PatternTsDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_domain_wd_pattern_ts_get_by_type_get_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_domain_wd_pattern_ts_get_by_type_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取指定类型的模式时序数据 Get pattern time-series data of a scenario by type  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_pattern_ts_get_by_type_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id: 方案ID scenario id
        :param str pattern_type: 模式类型 pattern type
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[PatternTsDto], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id',
            'pattern_type'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_domain_wd_pattern_ts_get_by_type_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('scenarioId', local_var_params['scenario_id']))  # noqa: E501
        if 'pattern_type' in local_var_params and local_var_params['pattern_type'] is not None:  # noqa: E501
            query_params.append(('patternType', local_var_params['pattern_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/domain-wd/pattern-ts/get-by-type', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PatternTsDto]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_domain_wd_pattern_ts_getlist_by_modelid_post(self, **kwargs):  # noqa: E501
        """根据模型id列表获取模式时序数据 Get pattern time-series data of a scenario by pattern muids  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_pattern_ts_getlist_by_modelid_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param GetPatternTsListyModelIdInput get_pattern_ts_listy_model_id_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[PatternTsDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_domain_wd_pattern_ts_getlist_by_modelid_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_domain_wd_pattern_ts_getlist_by_modelid_post_with_http_info(self, **kwargs):  # noqa: E501
        """根据模型id列表获取模式时序数据 Get pattern time-series data of a scenario by pattern muids  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_pattern_ts_getlist_by_modelid_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param GetPatternTsListyModelIdInput get_pattern_ts_listy_model_id_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[PatternTsDto], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'get_pattern_ts_listy_model_id_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_domain_wd_pattern_ts_getlist_by_modelid_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'get_pattern_ts_listy_model_id_input' in local_var_params:
            body_params = local_var_params['get_pattern_ts_listy_model_id_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/domain-wd/pattern-ts/getlist-by-modelid', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PatternTsDto]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_domain_wd_pattern_ts_resave_post(self, **kwargs):  # noqa: E501
        """保存模式时序数据，原有模式时序数据会被删除 Save pattern time-series data, old pattern time-series data will be deleted  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_pattern_ts_resave_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddPatternTsInput add_pattern_ts_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_domain_wd_pattern_ts_resave_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_domain_wd_pattern_ts_resave_post_with_http_info(self, **kwargs):  # noqa: E501
        """保存模式时序数据，原有模式时序数据会被删除 Save pattern time-series data, old pattern time-series data will be deleted  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_pattern_ts_resave_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddPatternTsInput add_pattern_ts_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_pattern_ts_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_domain_wd_pattern_ts_resave_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_pattern_ts_input' in local_var_params:
            body_params = local_var_params['add_pattern_ts_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/domain-wd/pattern-ts/resave', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_model_information_domain_wd_pattern_ts_update_post(self, **kwargs):  # noqa: E501
        """修改模式时序数据 Update pattern time-series data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_pattern_ts_update_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdatePatternTsInput update_pattern_ts_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_model_information_domain_wd_pattern_ts_update_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_model_information_domain_wd_pattern_ts_update_post_with_http_info(self, **kwargs):  # noqa: E501
        """修改模式时序数据 Update pattern time-series data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_model_information_domain_wd_pattern_ts_update_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdatePatternTsInput update_pattern_ts_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_pattern_ts_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_model_information_domain_wd_pattern_ts_update_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_pattern_ts_input' in local_var_params:
            body_params = local_var_params['update_pattern_ts_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/model-information/domain-wd/pattern-ts/update', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

# flake8: noqa

"""
    result-analysis-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from dhicn_result_analysis_service.api.catchment_api import CatchmentApi
from dhicn_result_analysis_service.api.log_simulation_api import LogSimulationApi
from dhicn_result_analysis_service.api.m2_d_api import M2DApi
from dhicn_result_analysis_service.api.network_api import NetworkApi
from dhicn_result_analysis_service.api.rain_log_api import RainLogApi
from dhicn_result_analysis_service.api.river_api import RiverApi
from dhicn_result_analysis_service.api.scenario_api import ScenarioApi
from dhicn_result_analysis_service.api.urban_cs_result_analysis_api import UrbanCsResultAnalysisApi
from dhicn_result_analysis_service.api.urban_flooding_api import UrbanFloodingApi
from dhicn_result_analysis_service.api.urban_wd_result_analysis_api import UrbanWdResultAnalysisApi
from dhicn_result_analysis_service.api.urban_wd_time_series_api import UrbanWdTimeSeriesApi
from dhicn_result_analysis_service.api.wd_test_api import WDTestApi
from dhicn_result_analysis_service.api.wq_test_api import WQTestApi
from dhicn_result_analysis_service.api.water_hammer_result_analysis_api import WaterHammerResultAnalysisApi
from dhicn_result_analysis_service.api.wq_result_analysis_api import WqResultAnalysisApi

# import ApiClient
from dhicn_result_analysis_service.api_client import ApiClient
from dhicn_result_analysis_service.configuration import Configuration
from dhicn_result_analysis_service.exceptions import OpenApiException
from dhicn_result_analysis_service.exceptions import ApiTypeError
from dhicn_result_analysis_service.exceptions import ApiValueError
from dhicn_result_analysis_service.exceptions import ApiKeyError
from dhicn_result_analysis_service.exceptions import ApiException
# import models into sdk package
from dhicn_result_analysis_service.models.base_dynamic_output import BaseDynamicOutput
from dhicn_result_analysis_service.models.base_static_output import BaseStaticOutput
from dhicn_result_analysis_service.models.base_timeseries_batch_output import BaseTimeseriesBatchOutput
from dhicn_result_analysis_service.models.base_timeseries_output import BaseTimeseriesOutput
from dhicn_result_analysis_service.models.cs_current_model_output import CsCurrentModelOutput
from dhicn_result_analysis_service.models.cs_history_model_output import CsHistoryModelOutput
from dhicn_result_analysis_service.models.data_type_enum import DataTypeEnum
from dhicn_result_analysis_service.models.filter_condition_enum import FilterConditionEnum
from dhicn_result_analysis_service.models.filter_model_result_dto import FilterModelResultDto
from dhicn_result_analysis_service.models.flooding_risk_info import FloodingRiskInfo
from dhicn_result_analysis_service.models.flooding_risk_item import FloodingRiskItem
from dhicn_result_analysis_service.models.flushing_result_entity import FlushingResultEntity
from dhicn_result_analysis_service.models.gate_info import GateInfo
from dhicn_result_analysis_service.models.gate_statistic_info import GateStatisticInfo
from dhicn_result_analysis_service.models.gate_statistics_output import GateStatisticsOutput
from dhicn_result_analysis_service.models.geo_point_item import GeoPointItem
from dhicn_result_analysis_service.models.get_filter_model_result_input import GetFilterModelResultInput
from dhicn_result_analysis_service.models.get_statistic_result_input import GetStatisticResultInput
from dhicn_result_analysis_service.models.get_time_statistic_result_input import GetTimeStatisticResultInput
from dhicn_result_analysis_service.models.log_simulation_item import LogSimulationItem
from dhicn_result_analysis_service.models.m2_d_by_range_time_input import M2DByRangeTimeInput
from dhicn_result_analysis_service.models.m2_d_data_type_enum import M2DDataTypeEnum
from dhicn_result_analysis_service.models.m2_d_statistic_type_enum import M2DStatisticTypeEnum
from dhicn_result_analysis_service.models.model_result_branch_affected_info_output import ModelResultBranchAffectedInfoOutput
from dhicn_result_analysis_service.models.model_result_pipe_dispatch_statistic_output import ModelResultPipeDispatchStatisticOutput
from dhicn_result_analysis_service.models.model_result_pipe_pump_statistic_output import ModelResultPipePumpStatisticOutput
from dhicn_result_analysis_service.models.model_result_pipe_pump_volume_statistic_output import ModelResultPipePumpVolumeStatisticOutput
from dhicn_result_analysis_service.models.model_result_pipe_sewage_plant_avg_statistic_output import ModelResultPipeSewagePlantAvgStatisticOutput
from dhicn_result_analysis_service.models.model_result_pipe_sewage_plant_instant_statistic_output import ModelResultPipeSewagePlantInstantStatisticOutput
from dhicn_result_analysis_service.models.model_result_pipe_sewage_plant_statistic_output import ModelResultPipeSewagePlantStatisticOutput
from dhicn_result_analysis_service.models.model_result_pipe_smart_well_over_flow_statistic_output import ModelResultPipeSmartWellOverFlowStatisticOutput
from dhicn_result_analysis_service.models.model_result_pipe_smart_well_statistic_output import ModelResultPipeSmartWellStatisticOutput
from dhicn_result_analysis_service.models.model_result_pipe_smart_well_total_load_statistic_output import ModelResultPipeSmartWellTotalLoadStatisticOutput
from dhicn_result_analysis_service.models.model_result_pipe_storage_statistic_output import ModelResultPipeStorageStatisticOutput
from dhicn_result_analysis_service.models.model_result_pipe_valve_statistic_output import ModelResultPipeValveStatisticOutput
from dhicn_result_analysis_service.models.model_result_pipe_w_qs_output import ModelResultPipeWQsOutput
from dhicn_result_analysis_service.models.model_result_pipe_wq_input import ModelResultPipeWqInput
from dhicn_result_analysis_service.models.model_result_pipe_wq_output import ModelResultPipeWqOutput
from dhicn_result_analysis_service.models.model_result_river_control_statistic_output import ModelResultRiverControlStatisticOutput
from dhicn_result_analysis_service.models.model_result_river_dam_statistic_output import ModelResultRiverDamStatisticOutput
from dhicn_result_analysis_service.models.model_result_river_gate_pump_statistic_output import ModelResultRiverGatePumpStatisticOutput
from dhicn_result_analysis_service.models.model_result_river_gate_statistic_output import ModelResultRiverGateStatisticOutput
from dhicn_result_analysis_service.models.model_result_river_gate_total_statistic_output import ModelResultRiverGateTotalStatisticOutput
from dhicn_result_analysis_service.models.model_result_river_pump_statistic_output import ModelResultRiverPumpStatisticOutput
from dhicn_result_analysis_service.models.model_result_river_pump_total_statistic_output import ModelResultRiverPumpTotalStatisticOutput
from dhicn_result_analysis_service.models.model_result_river_qualified_statistic_output import ModelResultRiverQualifiedStatisticOutput
from dhicn_result_analysis_service.models.model_result_river_w_qs_output import ModelResultRiverWQsOutput
from dhicn_result_analysis_service.models.model_result_river_wq_input import ModelResultRiverWqInput
from dhicn_result_analysis_service.models.model_result_river_wq_output import ModelResultRiverWqOutput
from dhicn_result_analysis_service.models.model_result_river_wq_statistic_output import ModelResultRiverWqStatisticOutput
from dhicn_result_analysis_service.models.model_result_station_wq_statistic_input import ModelResultStationWqStatisticInput
from dhicn_result_analysis_service.models.model_result_station_wq_statistic_output import ModelResultStationWqStatisticOutput
from dhicn_result_analysis_service.models.model_result_times_output import ModelResultTimesOutput
from dhicn_result_analysis_service.models.model_result_wq_timeseries_input import ModelResultWqTimeseriesInput
from dhicn_result_analysis_service.models.model_result_wq_timeseries_output import ModelResultWqTimeseriesOutput
from dhicn_result_analysis_service.models.model_state_enum import ModelStateEnum
from dhicn_result_analysis_service.models.network_node_static_type_enum import NetworkNodeStaticTypeEnum
from dhicn_result_analysis_service.models.network_profile import NetworkProfile
from dhicn_result_analysis_service.models.network_statistics_output import NetworkStatisticsOutput
from dhicn_result_analysis_service.models.node_data_type_enum import NodeDataTypeEnum
from dhicn_result_analysis_service.models.node_item import NodeItem
from dhicn_result_analysis_service.models.node_profile_data import NodeProfileData
from dhicn_result_analysis_service.models.node_profile_data_profile_data_item import NodeProfileDataProfileDataItem
from dhicn_result_analysis_service.models.node_type_enum import NodeTypeEnum
from dhicn_result_analysis_service.models.object_id import ObjectId
from dhicn_result_analysis_service.models.outlet_result import OutletResult
from dhicn_result_analysis_service.models.overflow_statistics_item import OverflowStatisticsItem
from dhicn_result_analysis_service.models.pipe_data_type_enum import PipeDataTypeEnum
from dhicn_result_analysis_service.models.pipe_profile_item import PipeProfileItem
from dhicn_result_analysis_service.models.pipe_result import PipeResult
from dhicn_result_analysis_service.models.pump_info import PumpInfo
from dhicn_result_analysis_service.models.pump_statistic_info import PumpStatisticInfo
from dhicn_result_analysis_service.models.pump_statistics_output import PumpStatisticsOutput
from dhicn_result_analysis_service.models.pump_volume import PumpVolume
from dhicn_result_analysis_service.models.query_rain_output import QueryRainOutput
from dhicn_result_analysis_service.models.rainfall_runoff_summary_output import RainfallRunoffSummaryOutput
from dhicn_result_analysis_service.models.rainfall_status_enum import RainfallStatusEnum
from dhicn_result_analysis_service.models.remote_service_error_info import RemoteServiceErrorInfo
from dhicn_result_analysis_service.models.remote_service_error_response import RemoteServiceErrorResponse
from dhicn_result_analysis_service.models.remote_service_validation_error_info import RemoteServiceValidationErrorInfo
from dhicn_result_analysis_service.models.river_data_type_enum import RiverDataTypeEnum
from dhicn_result_analysis_service.models.river_profile import RiverProfile
from dhicn_result_analysis_service.models.river_water_level import RiverWaterLevel
from dhicn_result_analysis_service.models.river_water_level_profile_data_item import RiverWaterLevelProfileDataItem
from dhicn_result_analysis_service.models.rr_summary_per_catchment import RrSummaryPerCatchment
from dhicn_result_analysis_service.models.scenario_time_info import ScenarioTimeInfo
from dhicn_result_analysis_service.models.sensitive_points_statistic import SensitivePointsStatistic
from dhicn_result_analysis_service.models.sensitive_points_timeseries import SensitivePointsTimeseries
from dhicn_result_analysis_service.models.smart_well_valve_ts_data import SmartWellValveTsData
from dhicn_result_analysis_service.models.statistic_model_id_item_dto import StatisticModelIdItemDto
from dhicn_result_analysis_service.models.statistic_time_item_dto import StatisticTimeItemDto
from dhicn_result_analysis_service.models.statistic_type_enum import StatisticTypeEnum
from dhicn_result_analysis_service.models.statistics_model_id_result_dto import StatisticsModelIdResultDto
from dhicn_result_analysis_service.models.statistics_time_result_dto import StatisticsTimeResultDto
from dhicn_result_analysis_service.models.storage_data import StorageData
from dhicn_result_analysis_service.models.string_page import StringPage
from dhicn_result_analysis_service.models.structure_type_enum import StructureTypeEnum
from dhicn_result_analysis_service.models.structures_item_enum import StructuresItemEnum
from dhicn_result_analysis_service.models.sys_wd_data_type_enum import SysWdDataTypeEnum
from dhicn_result_analysis_service.models.trace_wq_close_pipe import TraceWqClosePipe
from dhicn_result_analysis_service.models.trace_wq_close_pipe_result import TraceWqClosePipeResult
from dhicn_result_analysis_service.models.trace_wq_valve_info import TraceWqValveInfo
from dhicn_result_analysis_service.models.ts_pair_object import TsPairObject
from dhicn_result_analysis_service.models.ts_pairs import TsPairs
from dhicn_result_analysis_service.models.user_info import UserInfo
from dhicn_result_analysis_service.models.valve_statistic_list import ValveStatisticList
from dhicn_result_analysis_service.models.valve_statistics_output import ValveStatisticsOutput
from dhicn_result_analysis_service.models.wd_batch_structure_timeseries_input import WdBatchStructureTimeseriesInput
from dhicn_result_analysis_service.models.wd_batch_timeseries_input import WdBatchTimeseriesInput
from dhicn_result_analysis_service.models.wd_calculate_type_enum import WdCalculateTypeEnum
from dhicn_result_analysis_service.models.wd_data_type_enum import WdDataTypeEnum
from dhicn_result_analysis_service.models.wd_feature_type_enum import WdFeatureTypeEnum
from dhicn_result_analysis_service.models.wd_history_model_input import WdHistoryModelInput
from dhicn_result_analysis_service.models.wd_history_model_output import WdHistoryModelOutput
from dhicn_result_analysis_service.models.wd_statistic_shut_off_user_dto import WdStatisticShutOffUserDto
from dhicn_result_analysis_service.models.wd_zone_model_result_input import WdZoneModelResultInput
from dhicn_result_analysis_service.models.wd_zone_model_result_output import WdZoneModelResultOutput
from dhicn_result_analysis_service.models.wq_info_value import WqInfoValue
from dhicn_result_analysis_service.models.wq_instant_statistic_info import WqInstantStatisticInfo
from dhicn_result_analysis_service.models.wq_load_info import WqLoadInfo
from dhicn_result_analysis_service.models.wq_max_statistic import WqMaxStatistic
from dhicn_result_analysis_service.models.wq_statistic import WqStatistic
from dhicn_result_analysis_service.models.wq_value_info import WqValueInfo




# coding: utf-8

"""
    scenario-manager-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_scenario_manager_service.configuration import Configuration


class Group(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'parent_id': 'str',
        'group_type': 'int',
        'item_ref': 'str',
        'group_family': 'str',
        'group_level': 'str',
        'item_id': 'str',
        'version': 'str',
        'tenant_id': 'str',
        'parent': 'Group',
        'path': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'parent_id': 'parentId',
        'group_type': 'groupType',
        'item_ref': 'itemRef',
        'group_family': 'groupFamily',
        'group_level': 'groupLevel',
        'item_id': 'itemId',
        'version': 'version',
        'tenant_id': 'tenantId',
        'parent': 'parent',
        'path': 'path'
    }

    def __init__(self, id=None, name=None, parent_id=None, group_type=None, item_ref=None, group_family=None, group_level=None, item_id=None, version=None, tenant_id=None, parent=None, path=None, local_vars_configuration=None):  # noqa: E501
        """Group - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._parent_id = None
        self._group_type = None
        self._item_ref = None
        self._group_family = None
        self._group_level = None
        self._item_id = None
        self._version = None
        self._tenant_id = None
        self._parent = None
        self._path = None
        self.discriminator = None

        self.id = id
        self.name = name
        self.parent_id = parent_id
        if group_type is not None:
            self.group_type = group_type
        self.item_ref = item_ref
        self.group_family = group_family
        self.group_level = group_level
        if item_id is not None:
            self.item_id = item_id
        if version is not None:
            self.version = version
        self.tenant_id = tenant_id
        if parent is not None:
            self.parent = parent
        self.path = path

    @property
    def id(self):
        """Gets the id of this Group.  # noqa: E501


        :return: The id of this Group.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Group.


        :param id: The id of this Group.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this Group.  # noqa: E501


        :return: The name of this Group.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Group.


        :param name: The name of this Group.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 255):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `255`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 0):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `0`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and not re.search(r'^[^\\/:*?<>"|]+$', name)):  # noqa: E501
            raise ValueError(r'Invalid value for `name`, must be a follow pattern or equal to `/^[^\\/:*?<>"|]+$/`')  # noqa: E501

        self._name = name

    @property
    def parent_id(self):
        """Gets the parent_id of this Group.  # noqa: E501


        :return: The parent_id of this Group.  # noqa: E501
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        """Sets the parent_id of this Group.


        :param parent_id: The parent_id of this Group.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and parent_id is None:  # noqa: E501
            raise ValueError("Invalid value for `parent_id`, must not be `None`")  # noqa: E501

        self._parent_id = parent_id

    @property
    def group_type(self):
        """Gets the group_type of this Group.  # noqa: E501


        :return: The group_type of this Group.  # noqa: E501
        :rtype: int
        """
        return self._group_type

    @group_type.setter
    def group_type(self, group_type):
        """Sets the group_type of this Group.


        :param group_type: The group_type of this Group.  # noqa: E501
        :type: int
        """

        self._group_type = group_type

    @property
    def item_ref(self):
        """Gets the item_ref of this Group.  # noqa: E501


        :return: The item_ref of this Group.  # noqa: E501
        :rtype: str
        """
        return self._item_ref

    @item_ref.setter
    def item_ref(self, item_ref):
        """Sets the item_ref of this Group.


        :param item_ref: The item_ref of this Group.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                item_ref is not None and len(item_ref) > 100):
            raise ValueError("Invalid value for `item_ref`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                item_ref is not None and len(item_ref) < 0):
            raise ValueError("Invalid value for `item_ref`, length must be greater than or equal to `0`")  # noqa: E501

        self._item_ref = item_ref

    @property
    def group_family(self):
        """Gets the group_family of this Group.  # noqa: E501


        :return: The group_family of this Group.  # noqa: E501
        :rtype: str
        """
        return self._group_family

    @group_family.setter
    def group_family(self, group_family):
        """Sets the group_family of this Group.


        :param group_family: The group_family of this Group.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and group_family is None:  # noqa: E501
            raise ValueError("Invalid value for `group_family`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                group_family is not None and len(group_family) > 100):
            raise ValueError("Invalid value for `group_family`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                group_family is not None and len(group_family) < 0):
            raise ValueError("Invalid value for `group_family`, length must be greater than or equal to `0`")  # noqa: E501

        self._group_family = group_family

    @property
    def group_level(self):
        """Gets the group_level of this Group.  # noqa: E501


        :return: The group_level of this Group.  # noqa: E501
        :rtype: str
        """
        return self._group_level

    @group_level.setter
    def group_level(self, group_level):
        """Sets the group_level of this Group.


        :param group_level: The group_level of this Group.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and group_level is None:  # noqa: E501
            raise ValueError("Invalid value for `group_level`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                group_level is not None and len(group_level) > 1000):
            raise ValueError("Invalid value for `group_level`, length must be less than or equal to `1000`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                group_level is not None and len(group_level) < 0):
            raise ValueError("Invalid value for `group_level`, length must be greater than or equal to `0`")  # noqa: E501

        self._group_level = group_level

    @property
    def item_id(self):
        """Gets the item_id of this Group.  # noqa: E501


        :return: The item_id of this Group.  # noqa: E501
        :rtype: str
        """
        return self._item_id

    @item_id.setter
    def item_id(self, item_id):
        """Sets the item_id of this Group.


        :param item_id: The item_id of this Group.  # noqa: E501
        :type: str
        """

        self._item_id = item_id

    @property
    def version(self):
        """Gets the version of this Group.  # noqa: E501


        :return: The version of this Group.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Group.


        :param version: The version of this Group.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def tenant_id(self):
        """Gets the tenant_id of this Group.  # noqa: E501


        :return: The tenant_id of this Group.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this Group.


        :param tenant_id: The tenant_id of this Group.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def parent(self):
        """Gets the parent of this Group.  # noqa: E501


        :return: The parent of this Group.  # noqa: E501
        :rtype: Group
        """
        return self._parent

    @parent.setter
    def parent(self, parent):
        """Sets the parent of this Group.


        :param parent: The parent of this Group.  # noqa: E501
        :type: Group
        """

        self._parent = parent

    @property
    def path(self):
        """Gets the path of this Group.  # noqa: E501


        :return: The path of this Group.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this Group.


        :param path: The path of this Group.  # noqa: E501
        :type: str
        """

        self._path = path

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Group):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Group):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    wwtp-paas-infrastructure-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wwtp_infrastructure_service.configuration import Configuration


class ModelNodeConfigInputOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'node_code': 'str',
        'node_name': 'str',
        'unit': 'str',
        'data_type': 'str',
        'model_name': 'str'
    }

    attribute_map = {
        'node_code': 'nodeCode',
        'node_name': 'nodeName',
        'unit': 'unit',
        'data_type': 'dataType',
        'model_name': 'modelName'
    }

    def __init__(self, node_code=None, node_name=None, unit=None, data_type=None, model_name=None, local_vars_configuration=None):  # noqa: E501
        """ModelNodeConfigInputOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._node_code = None
        self._node_name = None
        self._unit = None
        self._data_type = None
        self._model_name = None
        self.discriminator = None

        self.node_code = node_code
        self.node_name = node_name
        self.unit = unit
        self.data_type = data_type
        self.model_name = model_name

    @property
    def node_code(self):
        """Gets the node_code of this ModelNodeConfigInputOutput.  # noqa: E501

        模型点位编码 model node code  # noqa: E501

        :return: The node_code of this ModelNodeConfigInputOutput.  # noqa: E501
        :rtype: str
        """
        return self._node_code

    @node_code.setter
    def node_code(self, node_code):
        """Sets the node_code of this ModelNodeConfigInputOutput.

        模型点位编码 model node code  # noqa: E501

        :param node_code: The node_code of this ModelNodeConfigInputOutput.  # noqa: E501
        :type: str
        """

        self._node_code = node_code

    @property
    def node_name(self):
        """Gets the node_name of this ModelNodeConfigInputOutput.  # noqa: E501

        模型点位名称 mode node name  # noqa: E501

        :return: The node_name of this ModelNodeConfigInputOutput.  # noqa: E501
        :rtype: str
        """
        return self._node_name

    @node_name.setter
    def node_name(self, node_name):
        """Sets the node_name of this ModelNodeConfigInputOutput.

        模型点位名称 mode node name  # noqa: E501

        :param node_name: The node_name of this ModelNodeConfigInputOutput.  # noqa: E501
        :type: str
        """

        self._node_name = node_name

    @property
    def unit(self):
        """Gets the unit of this ModelNodeConfigInputOutput.  # noqa: E501

        单位 data unit  # noqa: E501

        :return: The unit of this ModelNodeConfigInputOutput.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this ModelNodeConfigInputOutput.

        单位 data unit  # noqa: E501

        :param unit: The unit of this ModelNodeConfigInputOutput.  # noqa: E501
        :type: str
        """

        self._unit = unit

    @property
    def data_type(self):
        """Gets the data_type of this ModelNodeConfigInputOutput.  # noqa: E501

        数据类型，如负荷、浓度等 data type like Load, Concentration, etc.  # noqa: E501

        :return: The data_type of this ModelNodeConfigInputOutput.  # noqa: E501
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """Sets the data_type of this ModelNodeConfigInputOutput.

        数据类型，如负荷、浓度等 data type like Load, Concentration, etc.  # noqa: E501

        :param data_type: The data_type of this ModelNodeConfigInputOutput.  # noqa: E501
        :type: str
        """

        self._data_type = data_type

    @property
    def model_name(self):
        """Gets the model_name of this ModelNodeConfigInputOutput.  # noqa: E501

        模板模型名称（即模板方案名称） template model name  # noqa: E501

        :return: The model_name of this ModelNodeConfigInputOutput.  # noqa: E501
        :rtype: str
        """
        return self._model_name

    @model_name.setter
    def model_name(self, model_name):
        """Sets the model_name of this ModelNodeConfigInputOutput.

        模板模型名称（即模板方案名称） template model name  # noqa: E501

        :param model_name: The model_name of this ModelNodeConfigInputOutput.  # noqa: E501
        :type: str
        """

        self._model_name = model_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModelNodeConfigInputOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ModelNodeConfigInputOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    digital-twin-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_digital_twin_service.configuration import Configuration


class PrecisionModel(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'is_floating': 'bool',
        'maximum_significant_digits': 'int',
        'scale': 'float',
        'precision_model_type': 'int'
    }

    attribute_map = {
        'is_floating': 'isFloating',
        'maximum_significant_digits': 'maximumSignificantDigits',
        'scale': 'scale',
        'precision_model_type': 'precisionModelType'
    }

    def __init__(self, is_floating=None, maximum_significant_digits=None, scale=None, precision_model_type=None, local_vars_configuration=None):  # noqa: E501
        """PrecisionModel - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._is_floating = None
        self._maximum_significant_digits = None
        self._scale = None
        self._precision_model_type = None
        self.discriminator = None

        if is_floating is not None:
            self.is_floating = is_floating
        if maximum_significant_digits is not None:
            self.maximum_significant_digits = maximum_significant_digits
        if scale is not None:
            self.scale = scale
        if precision_model_type is not None:
            self.precision_model_type = precision_model_type

    @property
    def is_floating(self):
        """Gets the is_floating of this PrecisionModel.  # noqa: E501


        :return: The is_floating of this PrecisionModel.  # noqa: E501
        :rtype: bool
        """
        return self._is_floating

    @is_floating.setter
    def is_floating(self, is_floating):
        """Sets the is_floating of this PrecisionModel.


        :param is_floating: The is_floating of this PrecisionModel.  # noqa: E501
        :type: bool
        """

        self._is_floating = is_floating

    @property
    def maximum_significant_digits(self):
        """Gets the maximum_significant_digits of this PrecisionModel.  # noqa: E501


        :return: The maximum_significant_digits of this PrecisionModel.  # noqa: E501
        :rtype: int
        """
        return self._maximum_significant_digits

    @maximum_significant_digits.setter
    def maximum_significant_digits(self, maximum_significant_digits):
        """Sets the maximum_significant_digits of this PrecisionModel.


        :param maximum_significant_digits: The maximum_significant_digits of this PrecisionModel.  # noqa: E501
        :type: int
        """

        self._maximum_significant_digits = maximum_significant_digits

    @property
    def scale(self):
        """Gets the scale of this PrecisionModel.  # noqa: E501


        :return: The scale of this PrecisionModel.  # noqa: E501
        :rtype: float
        """
        return self._scale

    @scale.setter
    def scale(self, scale):
        """Sets the scale of this PrecisionModel.


        :param scale: The scale of this PrecisionModel.  # noqa: E501
        :type: float
        """

        self._scale = scale

    @property
    def precision_model_type(self):
        """Gets the precision_model_type of this PrecisionModel.  # noqa: E501

        0-Floating 1-FloatingSingle 2-Fixed   # noqa: E501

        :return: The precision_model_type of this PrecisionModel.  # noqa: E501
        :rtype: int
        """
        return self._precision_model_type

    @precision_model_type.setter
    def precision_model_type(self, precision_model_type):
        """Sets the precision_model_type of this PrecisionModel.

        0-Floating 1-FloatingSingle 2-Fixed   # noqa: E501

        :param precision_model_type: The precision_model_type of this PrecisionModel.  # noqa: E501
        :type: int
        """
        allowed_values = [0, 1, 2]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and precision_model_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `precision_model_type` ({0}), must be one of {1}"  # noqa: E501
                .format(precision_model_type, allowed_values)
            )

        self._precision_model_type = precision_model_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PrecisionModel):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PrecisionModel):
            return True

        return self.to_dict() != other.to_dict()
